**********
Components
**********
.. automodule:: networkx.algorithms.components

Connectivity
------------
.. autosummary::
   :toctree: generated/

   is_connected
   number_connected_components
   connected_components
   node_connected_component

Strong connectivity
-------------------
.. autosummary::
   :toctree: generated/

   is_strongly_connected
   number_strongly_connected_components
   strongly_connected_components
   strongly_connected_components_recursive
   kosaraju_strongly_connected_components
   condensation

Weak connectivity
-----------------
.. autosummary::
   :toctree: generated/

   is_weakly_connected
   number_weakly_connected_components
   weakly_connected_components

Attracting components
---------------------
.. autosummary::
   :toctree: generated/

   is_attracting_component
   number_attracting_components
   attracting_components

Biconnected components
----------------------
.. autosummary::
   :toctree: generated/

   is_biconnected
   biconnected_components
   biconnected_component_edges
   articulation_points

Semiconnectedness
-----------------
.. autosummary::
   :toctree: generated/

   is_semiconnected
